import { vehicle } from "../../../../entity/unit/vehicle/vehicle";
import { VehicleViewModel } from "../../../../viewmodel/admin/unit/vehicle/vehicle.models";
import VehicleTypeFactory from "./vehicleType";

export default abstract class VehicleFactory {
  /**
   * @description map record to vehicle
   * @param {vehicle} record
   * @returns {VehicleViewModel}
   */
  public static mapToSingle(record: vehicle): VehicleViewModel {
    return {
      id: record.id,
      code: record?.code,
      name: record.name,
      location: record.location,
      commissioned: record.commissioned,
      decommissioned: record?.decommissioned,
      vehicleTypeId: record?.vehicleTypeId,
      vehicleType: record?.vehicleType ? VehicleTypeFactory.mapToSingle(record.vehicleType) : null,
    };
  }

  /**
   * @description map records to vehicle
   * @param {Array<vehicle>} records
   * @returns {Array<VehicleViewModel>}
   */
  public static mapToBase(records: Array<vehicle>): Array<VehicleViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
